@@ -1,6 +1,5 @@
 import datetime
-
-from dateutil.tz import tzoffset
+from datetime import timezone
 
 from hcloud.isos.domain import Iso
 
@@ -9,5 +8,5 @@ class TestIso:
     def test_deprecated_is_datetime(self):
         iso = Iso(id=1, deprecated="2016-01-30T23:50+00:00")
         assert iso.deprecated == datetime.datetime(
-            2016, 1, 30, 23, 50, tzinfo=tzoffset(None, 0)
+            2016, 1, 30, 23, 50, tzinfo=timezone.utc
         )
